@@ -9,21 +9,8 @@ import sim2bids.preprocess.preprocess as prep
 import sim2bids.templates.templates as temp
 from sim2bids import sim2bids
 from sim2bids.convert import convert
-from sim2bids.generate import subjects
 
 
-def get_all_files(new_files, old_files, path):
-    all_files = new_files
-
-    # for file in old_files:
-    #
-    #
-    #
-    #     if subjects.accepted(file):
-    #         all_files.append(os.path.join(path, file))
-
-    return all_files
-
 def reset_values():
     prep.reset_index()
     subj.TO_RENAME = None
@@ -44,18 +31,18 @@ def rm_tree(path: str = '../output'):
     except OSError:
         os.remove(path)
 
-    print('Removed all files...')
+    print('Removed all test files...')
 
 
 def get_selector(name):
-    return pn.widgets.Select(name=f'Specify {name}', value='skip', groups={
+    return pn.widgets.Select(name=f'Specify {name}', groups={
         'Network (net)': ['weights', 'distances', 'delays', 'speed', 'weights & nodes'],
-        'Coordinates (coord)': ['times', 'bold_times', 'centres', 'orientations', 'areas', 'hemispheres',
+        'Coordinates (coord)': ['times', 'centres', 'orientations', 'areas', 'hemispheres',
                                 'cortical', 'nodes', 'labels', 'vertices', 'faces', 'vnormals',
                                 'fnormals', 'sensors', 'app', 'map', 'volumes',
                                 'cartesian2d', 'cartesian3d', 'polar2d', 'polar3d'],
-        'Timeseries (ts)': ['ts', 'bold_ts', 'emp', 'vars', 'stimuli', 'noise', 'spikes', 'raster', 'events', 'hrf'],
-        'Spatial (spatial)': ['fc', 'map', 'emp_fc'],
+        'Timeseries (ts)': ['ts', 'emp', 'vars', 'stimuli', 'noise', 'spikes', 'raster', 'events'],
+        'Spatial (spatial)': ['fc', 'map'],
         'Code (code)': ['code'],
         'Skip file type': ['skip']
     })
@@ -88,11 +75,9 @@ def get_settings(json_editor, selected):
             if k == 'Units':
                 widget.append(pn.widgets.Select(name=f'Specify {k} (REQUIRED):', options=sim2bids.UNITS, value=''))
         else:
-            if k not in ['NumberOfRows', 'NumberOfColumns', 'CoordsRows', 'CoordsColumns',
-                         'ModelEq', 'ModelParam', 'SourceCode', 'SoftwareName', 'SoftwareRepository',
-                         'Network']:
+            if k not in ['NumberOfRows', 'NumberOfColumns', 'CoordsRows', 'CoordsColumns']:
                 widget.append(pn.widgets.TextInput(name=f'Specify {k} (REQUIRED):'))
-                # sim2bids.REQUIRED.append(k)
+                sim2bids.REQUIRED.append(k)
 
     # iterate over recommended fields
     for k in recommend:
